# Changelog

<!--next-version-placeholder-->

## v2.1.8 (2023-07-01)
### Documentation
* Update hyperlinks ([`68a4f66`](https://github.com/Stephen-RA-King/pynamer/commit/68a4f665b642795589c354bc3e192ff8038e19c6))
* Update docker image usage ([`9637e54`](https://github.com/Stephen-RA-King/pynamer/commit/9637e54529e1113daea1e6c1ce6b8bf785d16aa0))
* Minor case change ([`5c0535d`](https://github.com/Stephen-RA-King/pynamer/commit/5c0535d78b48a2efdaede61ff675359c78df135b))
* Add openssf badge scorecard ([`779a9fe`](https://github.com/Stephen-RA-King/pynamer/commit/779a9fec1e400cfd3400ad5dcace6f9121de5bc3))
* Update openssf badge ([`d196617`](https://github.com/Stephen-RA-King/pynamer/commit/d1966179c7dcec1ac872595b8278ad5501bafd2e))
* Add openssf details ([`6fe62f8`](https://github.com/Stephen-RA-King/pynamer/commit/6fe62f8f5450949f4e37638f293457052061de61))

## v2.1.7 (2023-06-19)
### Fix
* Account for hompepoage beginning with http: ([`d9dcb50`](https://github.com/Stephen-RA-King/pynamer/commit/d9dcb50b4e6321d681a16aeba88bc2a2908f1005))

## v2.1.6 (2023-06-17)
### Fix
* Error message regarding pypirc file before registration ([`ded4143`](https://github.com/Stephen-RA-King/pynamer/commit/ded4143062a1e2fb5cf74c2912dea692d64fac17))

### Documentation
* Update logo ([`6be0f9a`](https://github.com/Stephen-RA-King/pynamer/commit/6be0f9ae77e6b63f382e1a490b57153a589a8920))
* Add missing docstrings ([`1377322`](https://github.com/Stephen-RA-King/pynamer/commit/1377322620a7894bc036021c9cde50bcd4cc732b))
* Update help screen image ([`7ce744b`](https://github.com/Stephen-RA-King/pynamer/commit/7ce744b6ad94610ebe0eee5158b46db359f73d85))

## v2.1.5 (2023-06-13)
### Fix
* Typeerror for github license ([`bb7bd2a`](https://github.com/Stephen-RA-King/pynamer/commit/bb7bd2aafef6a78db971e6fda7c4e93978088c9e))

### Documentation
* Minor updates ([`e4e3721`](https://github.com/Stephen-RA-King/pynamer/commit/e4e3721ec3e8e541aa1fc5d746cf048e5c157f28))

## v2.1.4 (2023-06-08)


## v2.1.3 (2023-06-07)
### Fix
* Regex for package names ([`756c6ff`](https://github.com/Stephen-RA-King/pynamer/commit/756c6ff297ca872ae3805df0ce25064cd4e518a2))

## v2.1.2 (2023-06-06)
### Documentation
* Update documentation ([`cf7ea92`](https://github.com/Stephen-RA-King/pynamer/commit/cf7ea92cb25354a2e7378d5fe44e24293ecf43dd))

## v2.1.1 (2023-06-06)
### Fix
* Missing dependencies ([`cd5027f`](https://github.com/Stephen-RA-King/pynamer/commit/cd5027fe5bbd95694658448b25ce5702f1fca986))

## v2.1.0 (2023-06-06)
### Feature
* Option to display github statistics ([`4ce5654`](https://github.com/Stephen-RA-King/pynamer/commit/4ce5654dcc6447b0518de9fd64f4c15fc6258e0f))

## v2.0.3 (2023-06-02)
### Fix
* Json formatting ([`892a454`](https://github.com/Stephen-RA-King/pynamer/commit/892a454d47c868973978e54be89f472ae351b455))

## v2.0.2 (2023-05-31)
### Fix
* Account for nonetype returned in json data ([`39f245c`](https://github.com/Stephen-RA-King/pynamer/commit/39f245c41b17add26ed9399dbb3c376cd395d79b))

## v2.0.1 (2023-05-29)
### Documentation
* Final updates ([`6c85802`](https://github.com/Stephen-RA-King/pynamer/commit/6c85802a132e91586d8d21c0ceb6dcf8f011264d))

## v2.0.0 (2023-05-24)
### Documentation
* Update citation ([`6cd655b`](https://github.com/Stephen-RA-King/pynamer/commit/6cd655bc1c9672fd5f64cbf63a78fc739a141328))

## v1.3.4 (2023-05-22)
### Documentation
* Fix type ([`a0cc3e1`](https://github.com/Stephen-RA-King/pynamer/commit/a0cc3e1b63cc3d147dea05085f7c9ecc80944815))
* Add documentation assets ([`eb45590`](https://github.com/Stephen-RA-King/pynamer/commit/eb455904f0c2dc73410e318e3bbe50b7d03a7273))

## v1.3.3 (2023-05-21)


## v1.3.2 (2023-05-21)
### Fix
* Add .pre-commit-config.yaml to mypy config ([`514c74f`](https://github.com/Stephen-RA-King/pynamer/commit/514c74f06091f4e28d82f4bd937aa44f4c552753))
* Remove function in minimalist __init__ ([`1d74fbb`](https://github.com/Stephen-RA-King/pynamer/commit/1d74fbb18265b13ee25d7c49a03705e6284985c2))
* Type hint annotations for importlib traversible ([`a579dca`](https://github.com/Stephen-RA-King/pynamer/commit/a579dcab34862fc72e21726316ca9e685cd84938))

### Documentation
* Update help text ([`c763420`](https://github.com/Stephen-RA-King/pynamer/commit/c763420d2a24b5fb682a4d61288e873a8019d8c6))
* Minor updates ([`145ddcd`](https://github.com/Stephen-RA-King/pynamer/commit/145ddcde8fd1e8680180689cff6c9f644a52204b))
* Update badges ([`b6eec6c`](https://github.com/Stephen-RA-King/pynamer/commit/b6eec6c88896c50d1e81eb3c9e5bd24208cab1fc))

## v1.3.1 (2023-05-17)
### Fix
* Restore text in setup ([`087d094`](https://github.com/Stephen-RA-King/pynamer/commit/087d094a554a9c70738fefe57e4f469e08252b48))

### Documentation
* Update readme images ([`392ec09`](https://github.com/Stephen-RA-King/pynamer/commit/392ec09379268bca7f85b40d0319a4fec8a5a1c4))

## v1.4.0 (2023-05-16)


## v1.3.0 (2023-05-16)


## v1.2.1 (2023-05-16)
### Fix
* Missing resource files ([`48219fb`](https://github.com/Stephen-RA-King/pynamer/commit/48219fbe615071f5c7dd1d7a4c2eca1a459d9ab9))

## v1.2.0 (2023-05-15)
### Feature
* Add ability to change version & description ([`d4fd512`](https://github.com/Stephen-RA-King/pynamer/commit/d4fd512dbea2adec32ff7271f88053cb0d0bb3a8))

### Documentation
* Update help text ([`91a392e`](https://github.com/Stephen-RA-King/pynamer/commit/91a392e58a886d18c0537a8657bfc099d3b06351))

## v1.1.0 (2023-05-15)
### Feature
* Move config into its own module ([`f4a3839`](https://github.com/Stephen-RA-King/pynamer/commit/f4a3839d402177e4e1bdc98f5714e0cf4cf30a9d))
* Add support to change meta data ([`05ac6a5`](https://github.com/Stephen-RA-King/pynamer/commit/05ac6a50be538191bfcddb68e49e5ceff5673803))
* Add new support files ([`81d9b16`](https://github.com/Stephen-RA-King/pynamer/commit/81d9b1675dbd0f94ec5eaba77f27aeec5f7778d8))
* Add input of meta data ([`0aefe49`](https://github.com/Stephen-RA-King/pynamer/commit/0aefe49bbda9035c5d80f24ea78f27c3536e7944))

### Documentation
* Update help message in readme ([`ac55f7d`](https://github.com/Stephen-RA-King/pynamer/commit/ac55f7d61a58df35c7f65c0e235a32973a1368eb))
* Minor updates ([`c87f126`](https://github.com/Stephen-RA-King/pynamer/commit/c87f1268f18920f3f45764d21a9e20e9bcf72331))

## v1.0.0 (2023-05-12)
### Feature
* Add name validity check function + others ([`b520245`](https://github.com/Stephen-RA-King/pynamer/commit/b5202458752ea1298ab450269a1b3cd341907f1e))

### Fix
* Update and fix failing tests ([`2e67751`](https://github.com/Stephen-RA-King/pynamer/commit/2e677512a7c58a1c8115d7f6567bfc050391f086))
* Some broken tests ([`33227e8`](https://github.com/Stephen-RA-King/pynamer/commit/33227e804ef08ff74f69cfb3530084bd3043e18b))

### Documentation
* Add limitations section ([`741154d`](https://github.com/Stephen-RA-King/pynamer/commit/741154ddf0dc1cdaf6353b635acda33afa383254))
* Update pngs ([`8eec345`](https://github.com/Stephen-RA-King/pynamer/commit/8eec345e0e5a268f770c93ccab330dd978c8baeb))

## v0.5.7 (2023-05-09)


## v0.5.6 (2023-05-09)
### Fix
* Logic error in fanal analysis function ([`46dbee0`](https://github.com/Stephen-RA-King/pynamer/commit/46dbee0983cb7c97d2f11931222fbdf3f64cf7c6))
* Broken tests ([`5b92893`](https://github.com/Stephen-RA-King/pynamer/commit/5b9289364ab9ad770c744c70e181812f77b9627b))

### Documentation
* Remove useless doctring ([`9b7f342`](https://github.com/Stephen-RA-King/pynamer/commit/9b7f3426cb982ce6244214b10db17fbc527833bb))
* Update some docstrings ([`39ae8f5`](https://github.com/Stephen-RA-King/pynamer/commit/39ae8f5cafeb222ef2d120bf4023b22953e869aa))
* Add cheeseshop png ([`b445a68`](https://github.com/Stephen-RA-King/pynamer/commit/b445a6803b7017e3aed06b714f3dcf5918f74579))

## v0.5.5 (2023-05-03)
### Fix
* Creation of 'None' file ([`6cb2252`](https://github.com/Stephen-RA-King/pynamer/commit/6cb2252afb65680c128d96b3b0c2b5bbba05caaa))

### Documentation
* Minor updates to README ([`4056294`](https://github.com/Stephen-RA-King/pynamer/commit/4056294771190b2618d117ff93766137c7c497a0))
* Cleanup the png files ([`7ade6d1`](https://github.com/Stephen-RA-King/pynamer/commit/7ade6d143e53c54b39d5243e7609c754cfd8a5f4))

## v0.5.4 (2023-05-03)
### Fix
* _write_output_file function ([`2b1b730`](https://github.com/Stephen-RA-King/pynamer/commit/2b1b730b56cb43d6629673744c349b2e3106e4ba))

### Documentation
* Fix hyperlinks ([`ac1be78`](https://github.com/Stephen-RA-King/pynamer/commit/ac1be781c6fcb292ef77aba580ed2faecb08498b))
* Update README ([`74d3a3e`](https://github.com/Stephen-RA-King/pynamer/commit/74d3a3edfead24b1499422fb0ac3bd3b088f4fde))

## v0.5.3 (2023-05-02)
### Fix
* Some type hints and add docstrings ([`d5b212d`](https://github.com/Stephen-RA-King/pynamer/commit/d5b212daf2d8e4d96f0fd16435c0d58b240701d0))

### Documentation
* Add png files for README ([`1c8987f`](https://github.com/Stephen-RA-King/pynamer/commit/1c8987f8b2350b14dc887274dc0cb11589a658b6))

## v0.5.2 (2023-05-01)
### Fix
* Table colours and variable case ([`4a1d40e`](https://github.com/Stephen-RA-King/pynamer/commit/4a1d40e349c7849411eff2337ef8dd465b6398d6))

## v0.5.1 (2023-05-01)
### Fix
* Regex pattern for 10,000+ projects found ([`9ec94ea`](https://github.com/Stephen-RA-King/pynamer/commit/9ec94ea1bdd90244be0b4cf7e0941b40ad7bb2ba))

## v0.5.0 (2023-04-30)
### Feature
* Add pypi search function and rich tables ([`089356b`](https://github.com/Stephen-RA-King/pynamer/commit/089356b574a3eca65dfcac69951f335a97e5e063))

### Fix
* Total projects found ([`4b42701`](https://github.com/Stephen-RA-King/pynamer/commit/4b42701fc9655573918251179b44e21855adc09b))

### Documentation
* Minor updates ([`1521d13`](https://github.com/Stephen-RA-King/pynamer/commit/1521d13be80aaee3b745ecb2da6362fe4c488b94))

## v0.4.0 (2023-04-27)
### Feature
* Add generate_pypi_index & pypi_search_index functions ([`96ff544`](https://github.com/Stephen-RA-King/pynamer/commit/96ff54496f8f6455a1a011ac723fd05afa1c547b))

### Documentation
* Bump version ([`d985a36`](https://github.com/Stephen-RA-King/pynamer/commit/d985a36edb4ada5f59786e1c55fff832e56ca1ec))

## v0.3.1 (2023-04-26)
### Fix
* Numerous fixes to get a working script ([`5fb56cc`](https://github.com/Stephen-RA-King/pynamer/commit/5fb56cc77c5d6a5552dbf381abbb3100ded29f76))

## v0.3.0 (2023-04-25)
### Feature
* Add main function ([`15a10c2`](https://github.com/Stephen-RA-King/pynamer/commit/15a10c24d45d529049ebf4fec21d95d28964de1e))
* Add input and output file processing functions ([`0f56b9f`](https://github.com/Stephen-RA-King/pynamer/commit/0f56b9fecb405cac96fbf0fbe435d2a8e574a875))
* Add generate_pypi_index function ([`262de6e`](https://github.com/Stephen-RA-King/pynamer/commit/262de6e78be67263e991324e4c127a43a97a2249))
* Add cleanup function ([`8fa933a`](https://github.com/Stephen-RA-King/pynamer/commit/8fa933a7a6fc12d03e18d181b715fa7e6d9819e3))
* Add pypi build and upload functions ([`c83378e`](https://github.com/Stephen-RA-King/pynamer/commit/c83378e6b296f66a497757ee402c90b28467c888))
* Add ping methods ([`8b51135`](https://github.com/Stephen-RA-King/pynamer/commit/8b51135c639d889377f1070770b8683106d3040c))
* Add run_command subprocess method ([`9472253`](https://github.com/Stephen-RA-King/pynamer/commit/9472253c39da7960cda62df97e20b5207f6983b8))
* Add deleter method ([`1fcd901`](https://github.com/Stephen-RA-King/pynamer/commit/1fcd901c664a77e390545c5e7a2ca70bb9a042e0))

### Documentation
* Update examples ([`6f2e510`](https://github.com/Stephen-RA-King/pynamer/commit/6f2e510cf66876fb5fd4555f9dbf8f990674960e))
* Basic instructions in the readme ([`96a565e`](https://github.com/Stephen-RA-King/pynamer/commit/96a565e5ab330381aebd9d9e7e798a9b83318a47))
* Add svg files ([`2ea191a`](https://github.com/Stephen-RA-King/pynamer/commit/2ea191ad56a59fe6f187d589df8316803cd99467))
* Add zaphod.png ([`f0c582d`](https://github.com/Stephen-RA-King/pynamer/commit/f0c582d101ad06a2e00ce30a614e3dd7aa9e3eb9))
* Update header link ([`cc5a933`](https://github.com/Stephen-RA-King/pynamer/commit/cc5a93377d49d3fdab96d92364412e121f11f02e))
* Add new header image ([`26bcc59`](https://github.com/Stephen-RA-King/pynamer/commit/26bcc598307b79a76573a6cc75f9d2f39960d556))

## v0.2.0 (2023-04-21)
### Feature
* Add rename_project_dir and create_setup methods ([`a4dd537`](https://github.com/Stephen-RA-King/pynamer/commit/a4dd5379339591bc0e6ba5c3151e41bc3c006cc0))

## v0.1.0 (2023-04-21)
### Feature
* Initial commit ([`dad9386`](https://github.com/Stephen-RA-King/pynamer/commit/dad9386ab283c0904fbda8e2a50b8542331b58dd))

## 0.1.0 (2023-04-21)

### First Release of 'pynamer'
